# JaxGA - Jax Geometric Algebra
[![Build status](https://github.com/RobinKa/jaxga/workflows/Build%20Test%20Publish/badge.svg)](https://github.com/RobinKa/jaxga/actions) [![PyPI](https://badge.fury.io/py/jaxga.svg)](https://badge.fury.io/py/jaxga)

## Installation
Install using pip: `pip install jaxga`

Requirements:
- Python 3
- [jax](https://github.com/google/jax)
